@@ -13,19 +13,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_i18n import *  # noqa
+"""oslo.i18n integration module.
 
-_translators = TranslatorFactory(domain='zaqar')
+See https://docs.openstack.org/oslo.i18n/latest/user/usage.html .
+
+"""
+
+import oslo_i18n as i18n
+
+_translators = i18n.TranslatorFactory(domain='zaqar')
 
 # The primary translation function using the well-known name "_"
 _ = _translators.primary
-
-# Translators for log levels.
-#
-# The abbreviated names are meant to reflect the usual use of a short
-# name like '_'. The "L" is for "log" and the other letter comes from
-# the level.
-_LI = _translators.log_info
-_LW = _translators.log_warning
-_LE = _translators.log_error
-_LC = _translators.log_critical
