@@ -19,11 +19,16 @@ from oslo_config import cfg
 
 from zaqar.common import cache as oslo_cache
 from zaqar.common import decorators
+from zaqar.conf import default
 from zaqar.tests import base
 
 
 class TestDecorators(base.TestBase):
 
+    def setUp(self):
+        super(TestDecorators, self).setUp()
+        self.conf.register_opts(default.ALL_OPTS)
+
     def test_memoized_getattr(self):
 
         class TestClass(object):
@@ -41,12 +46,13 @@ class TestDecorators(base.TestBase):
         conf = cfg.ConfigOpts()
         oslo_cache.register_config(conf)
         conf.cache.backend = 'dogpile.cache.memory'
+        conf.cache.enabled = True
         cache = oslo_cache.get_cache(conf)
 
         sample_project = {
-            u'name': u'Cats Abound',
-            u'bits': b'\x80\x81\x82\x83\x84',
-            b'key': u'Value. \x80',
+            'name': 'Cats Abound',
+            'bits': b'\x80\x81\x82\x83\x84',
+            b'key': 'Value. \x80',
         }
 
         def create_key(user, project=None):
@@ -77,8 +83,7 @@ class TestDecorators(base.TestBase):
         self.assertEqual(1, instance.project_gets)
 
         # Should be in the cache now.
-        project = msgpack.unpackb(cache.get(create_key(*args)),
-                                  encoding='utf-8')
+        project = msgpack.unpackb(cache.get(create_key(*args)))
         self.assertEqual(sample_project, project)
 
         # Should read from the cache this time (counter will not
@@ -99,6 +104,7 @@ class TestDecorators(base.TestBase):
         conf = cfg.ConfigOpts()
         oslo_cache.register_config(conf)
         conf.cache.backend = 'dogpile.cache.memory'
+        conf.cache.enabled = True
         cache = oslo_cache.get_cache(conf)
 
         class TestClass(object):
@@ -121,7 +127,7 @@ class TestDecorators(base.TestBase):
         self.assertEqual(1, instance.user_gets)
 
         # Should be in the cache now.
-        user = msgpack.unpackb(cache.get(name), encoding='utf-8')
+        user = msgpack.unpackb(cache.get(name))
         self.assertEqual(name, user)
 
         # Should read from the cache this time (counter will not
@@ -139,3 +145,40 @@ class TestDecorators(base.TestBase):
 
             self.assertEqual(name, user)
             self.assertEqual(2 + i, instance.user_gets)
+
+    def test_api_version_manager(self):
+        self.config(enable_deprecated_api_versions=[])
+        # 1. Test accessing current API version
+        VERSION = {
+            'id': '1',
+            'status': 'CURRENT',
+            'updated': 'Just yesterday'
+        }
+
+        @decorators.api_version_manager(VERSION)
+        def public_endpoint_1(driver, conf):
+            return True
+
+        self.assertTrue(public_endpoint_1(None, self.conf))
+
+        # 2. Test accessing deprecated API version
+        VERSION = {
+            'id': '1',
+            'status': 'DEPRECATED',
+            'updated': 'A long time ago'
+        }
+
+        @decorators.api_version_manager(VERSION)
+        def public_endpoint_2(driver, conf):
+            self.fail('Deprecated API enabled')
+
+        public_endpoint_2(None, self.conf)
+
+        # 3. Test enabling deprecated API version
+        self.config(enable_deprecated_api_versions=['1'])
+
+        @decorators.api_version_manager(VERSION)
+        def public_endpoint_3(driver, conf):
+            return True
+
+        self.assertTrue(public_endpoint_3(None, self.conf))
