@@ -22,7 +22,6 @@ import uuid
 from oslo_utils import timeutils
 from pymongo import cursor
 import pymongo.errors
-import six
 from testtools import matchers
 
 from zaqar.common import cache as oslo_cache
@@ -273,7 +272,7 @@ class MongodbQueueTests(MongodbSetupMixin, base.QueueControllerTest):
     def test_raises_connection_error(self):
 
         with mock.patch.object(cursor.Cursor,
-                               'next' if six.PY2 else '__next__',
+                               '__next__',
                                spec=True) as method:
             error = pymongo.errors.ConnectionFailure()
             method.side_effect = error
@@ -314,10 +313,10 @@ class MongodbMessageTests(MongodbSetupMixin, base.MessageControllerTest):
         seed_marker1 = self.controller._get_counter(queue_name,
                                                     self.project)
         self.assertEqual(0, seed_marker1, 'First marker is 0')
-
+        uuid = '97b64000-2526-11e3-b088-d85c1300734c'
         for i in range(iterations):
-            self.controller.post(queue_name, [{'ttl': 60}],
-                                 'uuid', project=self.project)
+            self.controller.post(queue_name, [{'ttl': 60}], uuid,
+                                 project=self.project)
 
             marker1 = self.controller._get_counter(queue_name,
                                                    self.project)
