@@ -12,18 +12,16 @@
 # License for the specific language governing permissions and limitations under
 # the License.
 
-import six
-import uuid
-
 import falcon
 from falcon import testing as ftest
 from oslo_serialization import jsonutils
+from oslo_utils import uuidutils
 
 from zaqar import bootstrap
-from zaqar.common import configs
+from zaqar.conf import default
+from zaqar.conf import drivers_transport_wsgi
+from zaqar.conf import transport
 from zaqar import tests as testing
-from zaqar.transport import validation
-from zaqar.transport.wsgi import driver
 
 
 class TestBase(testing.TestBase):
@@ -36,14 +34,14 @@ class TestBase(testing.TestBase):
         if not self.config_file:
             self.skipTest("No config specified")
 
-        self.conf.register_opts(configs._GENERAL_OPTIONS)
-        self.conf.register_opts(validation._TRANSPORT_LIMITS_OPTIONS,
-                                group=validation._TRANSPORT_LIMITS_GROUP)
-        self.transport_cfg = self.conf[validation._TRANSPORT_LIMITS_GROUP]
+        self.conf.register_opts(default.ALL_OPTS)
+        self.conf.register_opts(transport.ALL_OPTS,
+                                group=transport.GROUP_NAME)
+        self.transport_cfg = self.conf[transport.GROUP_NAME]
 
-        self.conf.register_opts(driver._WSGI_OPTIONS,
-                                group=driver._WSGI_GROUP)
-        self.wsgi_cfg = self.conf[driver._WSGI_GROUP]
+        self.conf.register_opts(drivers_transport_wsgi.ALL_OPTS,
+                                group=drivers_transport_wsgi.GROUP_NAME)
+        self.wsgi_cfg = self.conf[drivers_transport_wsgi.GROUP_NAME]
 
         self.conf.unreliable = True
         self.conf.admin_mode = True
@@ -56,7 +54,7 @@ class TestBase(testing.TestBase):
         self.srmock = ftest.StartResponseMock()
 
         self.headers = {
-            'Client-ID': str(uuid.uuid4()),
+            'Client-ID': uuidutils.generate_uuid(),
             'X-ROLES': 'admin',
             'X-USER-ID': 'a12d157c7d0d41999096639078fd11fc',
             'X-TENANT-ID': 'abb69142168841fcaa2785791b92467f',
@@ -93,8 +91,7 @@ class TestBase(testing.TestBase):
         kwargs.pop('need_project_id', None)
         kwargs['headers'] = headers
         try:
-            if six.PY3:
-                path.encode('latin1').decode('utf-8', 'replace')
+            path.encode('latin1').decode('utf-8', 'replace')
         except UnicodeEncodeError:
             self.srmock.status = falcon.HTTP_400
             return
