@@ -12,25 +12,25 @@
 # License for the specific language governing permissions and limitations under
 # the License.
 
-import uuid
 
 import falcon
 from oslo_serialization import jsonutils
-import six.moves.urllib.parse as urlparse
+from oslo_utils import uuidutils
+from urllib import parse as urlparse
 
 from zaqar.tests.unit.transport.wsgi import base
 
 
-class TestHomeDocument(base.V2Base):
+class TestHomeDocument(base.V1_1Base):
 
     config_file = 'wsgi_mongodb.conf'
 
     def test_json_response(self):
         self.headers = {
-            'Client-ID': str(uuid.uuid4()),
+            'Client-ID': uuidutils.generate_uuid(),
             'X-Project-ID': '8383830383abc_'
         }
-        body = self.simulate_get(self.url_prefix, headers=self.headers)
+        body = self.simulate_get(self.url_prefix + '/', headers=self.headers)
         self.assertEqual(falcon.HTTP_200, self.srmock.status)
 
         content_type = self.srmock.headers_dict['Content-Type']
@@ -43,10 +43,10 @@ class TestHomeDocument(base.V2Base):
 
     def test_href_template(self):
         self.headers = {
-            'Client-ID': str(uuid.uuid4()),
+            'Client-ID': uuidutils.generate_uuid(),
             'X-Project-ID': '8383830383'
         }
-        body = self.simulate_get(self.url_prefix, headers=self.headers)
+        body = self.simulate_get(self.url_prefix + '/', headers=self.headers)
         self.assertEqual(falcon.HTTP_200, self.srmock.status)
         resp = jsonutils.loads(body[0])
         queue_href_template = resp['resources']['rel/queue']['href-template']
