@@ -13,12 +13,12 @@
 # the License.
 
 
+from unittest import mock
+
 import ddt
 import falcon
-import mock
 from oslo_serialization import jsonutils
 from oslo_utils import uuidutils
-import six
 
 from zaqar.storage import errors as storage_errors
 from zaqar import tests as testing
@@ -113,6 +113,7 @@ class TestQueueLifecycleMongoDB(base.V2Base):
         ref_doc['_dead_letter_queue'] = None
         ref_doc['_dead_letter_queue_messages_ttl'] = None
         ref_doc['_max_claim_count'] = None
+        ref_doc['_enable_encrypt_messages'] = False
         self.assertEqual(ref_doc, result_doc)
 
         # Stats empty queue
@@ -161,6 +162,7 @@ class TestQueueLifecycleMongoDB(base.V2Base):
         ref_doc['_dead_letter_queue'] = None
         ref_doc['_dead_letter_queue_messages_ttl'] = None
         ref_doc['_max_claim_count'] = None
+        ref_doc['_enable_encrypt_messages'] = False
         self.assertEqual(ref_doc, result_doc)
 
         # Stats empty queue
@@ -207,15 +209,12 @@ class TestQueueLifecycleMongoDB(base.V2Base):
         self.assertEqual(falcon.HTTP_201, self.srmock.status)
 
     def test_non_ascii_name(self):
-        test_params = ((u'/queues/non-ascii-n\u0153me', 'utf-8'),
-                       (u'/queues/non-ascii-n\xc4me', 'iso8859-1'))
+        test_params = (('/queues/non-ascii-n\u0153me', 'utf-8'),
+                       ('/queues/non-ascii-n\xc4me', 'iso8859-1'))
 
         for uri, enc in test_params:
             uri = self.url_prefix + uri
 
-            if six.PY2:
-                uri = uri.encode(enc)
-
             self.simulate_put(uri, headers=self.headers)
             self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
@@ -301,6 +300,7 @@ class TestQueueLifecycleMongoDB(base.V2Base):
         ref_doc['_dead_letter_queue'] = None
         ref_doc['_dead_letter_queue_messages_ttl'] = None
         ref_doc['_max_claim_count'] = None
+        ref_doc['_enable_encrypt_messages'] = False
         self.assertEqual(ref_doc, result_doc)
         self.assertEqual(falcon.HTTP_200, self.srmock.status)
 
@@ -358,7 +358,8 @@ class TestQueueLifecycleMongoDB(base.V2Base):
                           '_default_message_delay': 0,
                           '_dead_letter_queue': None,
                           '_dead_letter_queue_messages_ttl': None,
-                          '_max_claim_count': None}, result_doc)
+                          '_max_claim_count': None,
+                          '_enable_encrypt_messages': False}, result_doc)
 
         # remove metadata
         doc3 = '[{"op":"remove", "path": "/metadata/key1"}]'
@@ -383,7 +384,8 @@ class TestQueueLifecycleMongoDB(base.V2Base):
                           '_default_message_delay': 0,
                           '_dead_letter_queue': None,
                           '_dead_letter_queue_messages_ttl': None,
-                          '_max_claim_count': None}, result_doc)
+                          '_max_claim_count': None,
+                          '_enable_encrypt_messages': False}, result_doc)
 
         # replace non-existent metadata
         doc4 = '[{"op":"replace", "path": "/metadata/key3", "value":2}]'
@@ -501,7 +503,8 @@ class TestQueueLifecycleMongoDB(base.V2Base):
                           '_default_message_delay': 0,
                           '_dead_letter_queue': None,
                           '_dead_letter_queue_messages_ttl': None,
-                          '_max_claim_count': None},  result_doc)
+                          '_max_claim_count': None,
+                          '_enable_encrypt_messages': False},  result_doc)
 
         # queue filter
         result = self.simulate_get(self.queue_path, headers=header,
@@ -587,6 +590,13 @@ class TestQueueLifecycleMongoDB(base.V2Base):
         result_doc = jsonutils.loads(result[0])
         self.assertEqual(3, len(result_doc['queues']))
 
+        # List (filter query)
+        result = self.simulate_get(self.queue_path, headers=header,
+                                   query_string='with_count=true')
+
+        result_doc = jsonutils.loads(result[0])
+        self.assertEqual(3, result_doc['count'])
+
 
 class TestQueueLifecycleFaultyDriver(base.V2BaseFaulty):
 
