@@ -12,12 +12,13 @@
 # License for the specific language governing permissions and limitations under
 # the License.
 
-import uuid
+
+from unittest import mock
 
 import ddt
 import falcon
-import mock
 from oslo_serialization import jsonutils
+from oslo_utils import uuidutils
 
 from zaqar.common import auth
 from zaqar.notification import notifier
@@ -48,7 +49,7 @@ class TestSubscriptionsMongoDB(base.V2Base):
 
         self.project_id = '7e55e1a7exyz'
         self.headers = {
-            'Client-ID': str(uuid.uuid4()),
+            'Client-ID': uuidutils.generate_uuid(),
             'X-Project-ID': self.project_id
         }
         self.queue = 'fake-topic'
@@ -185,7 +186,7 @@ class TestSubscriptionsMongoDB(base.V2Base):
 
         query = 'limit={0}'.format(limit)
         if marker:
-            query += '&marker={1}'.format(marker)
+            query += '&marker={0}'.format(marker)
 
         resp = self.simulate_get(self.subscription_path,
                                  query_string=query,
@@ -226,7 +227,7 @@ class TestSubscriptionsMongoDB(base.V2Base):
     def test_list_returns_503_on_nopoolfound_exception(self):
         arbitrary_number = 644079696574693
         project_id = str(arbitrary_number)
-        client_id = str(uuid.uuid4())
+        client_id = uuidutils.generate_uuid()
         header = {
             'X-Project-ID': project_id,
             'Client-ID': client_id
@@ -282,6 +283,10 @@ class TestSubscriptionsMongoDB(base.V2Base):
         self.assertEqual(falcon.HTTP_200, self.srmock.status)
         next_subscriptions_list = jsonutils.loads(resp[0])['subscriptions']
         self.assertEqual(5, len(next_subscriptions_list))
+        # The subscriptions's age should be 0 at this moment. But in some
+        # unexpected case, such as slow test, the age maybe larger than 0.
+        self.assertGreaterEqual(next_subscriptions_list[0].pop('age'),
+                                subscriptions_list[10].pop('age'))
         self.assertEqual(subscriptions_list[10], next_subscriptions_list[0])
 
     def test_get_works(self):
@@ -360,6 +365,15 @@ class TestSubscriptionsMongoDB(base.V2Base):
                             headers=self.headers)
         self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
+    def test_patch_invalid_body(self):
+        resp = self.simulate_patch(self.subscription_path + '/x',
+                                   body='[1]',
+                                   headers=self.headers)
+        self.assertEqual(falcon.HTTP_400, self.srmock.status)
+        resp_doc = jsonutils.loads(resp[0])
+        self.assertEqual('Subscriptions must be a dict.',
+                         resp_doc['description'])
+
     def test_delete_works(self):
         self._create_subscription()
         resp = self.simulate_get(self.subscription_path,
@@ -429,3 +443,14 @@ class TestSubscriptionsMongoDB(base.V2Base):
         doc = '{"confirmed": true}'
         self.simulate_put(self.confirm_path, body=doc, headers=self.headers)
         self.assertEqual(falcon.HTTP_404, self.srmock.status)
+
+    def test_confirm_with_extra_spec(self):
+        self.headers['EXTRA-SPEC'] = 'messagecode:123456'
+        doc = '{"confirmed": true}'
+        resp = self._create_subscription()
+        resp_doc = jsonutils.loads(resp[0])
+        confirm_path = (self.url_prefix + '/queues/' + self.queue +
+                        '/subscriptions/' + resp_doc['subscription_id'] +
+                        '/confirm')
+        self.simulate_put(confirm_path, body=doc, headers=self.headers)
+        self.assertEqual(falcon.HTTP_204, self.srmock.status)
