@@ -13,54 +13,33 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import asyncio
 import socket
 
-from oslo_config import cfg
 from oslo_log import log as logging
-
-try:
-    import asyncio
-except ImportError:
-    import trollius as asyncio
+from oslo_utils import netutils
 
 from zaqar.common import decorators
+from zaqar.conf import drivers_transport_websocket
 from zaqar.i18n import _
-from zaqar.transport import auth
 from zaqar.transport import base
+from zaqar.transport.middleware import auth
 from zaqar.transport.websocket import factory
 
 
-_WS_OPTIONS = (
-    cfg.IPOpt('bind', default='127.0.0.1',
-              help='Address on which the self-hosting server will listen.'),
-
-    cfg.PortOpt('port', default=9000,
-                help='Port on which the self-hosting server will listen.'),
-
-    cfg.PortOpt('external-port',
-                help='Port on which the service is provided to the user.'),
-
-)
-
-_WS_GROUP = 'drivers:transport:websocket'
-
 LOG = logging.getLogger(__name__)
 
 
-def _config_options():
-    return [(_WS_GROUP, _WS_OPTIONS)]
-
-
 class Driver(base.DriverBase):
 
     def __init__(self, conf, api, cache):
         super(Driver, self).__init__(conf, None, None, None)
         self._api = api
         self._cache = cache
-        self._hostname = socket.gethostname()
 
-        self._conf.register_opts(_WS_OPTIONS, group=_WS_GROUP)
-        self._ws_conf = self._conf[_WS_GROUP]
+        self._conf.register_opts(drivers_transport_websocket.ALL_OPTS,
+                                 group=drivers_transport_websocket.GROUP_NAME)
+        self._ws_conf = self._conf[drivers_transport_websocket.GROUP_NAME]
 
         if self._conf.auth_strategy:
             auth_strategy = auth.strategy(self._conf.auth_strategy)
@@ -71,7 +50,8 @@ class Driver(base.DriverBase):
 
     @decorators.lazy_property(write=False)
     def factory(self):
-        uri = 'ws://' + self._ws_conf.bind + ':' + str(self._ws_conf.port)
+        uri = 'ws://' + netutils.escape_ipv6(self._ws_conf.bind) + ':' + \
+              str(self._ws_conf.port)
         return factory.ProtocolFactory(
             uri,
             handler=self._api,
@@ -85,30 +65,41 @@ class Driver(base.DriverBase):
         return factory.NotificationFactory(self.factory)
 
     def listen(self):
-        """Self-host using 'bind' and 'port' from the WS config group."""
+        """Self-host the WebSocket server.
 
-        msgtmpl = _(u'Serving on host %(bind)s:%(port)s')
+        It runs the WebSocket server using 'bind' and 'port' options from the
+        websocket config group, and the notifiton endpoint using the
+        'notification_bind' and 'notification_port' options.
+        """
+        msgtmpl = _('Serving on host %(bind)s:%(port)s')
         LOG.info(msgtmpl,
                  {'bind': self._ws_conf.bind, 'port': self._ws_conf.port})
 
         loop = asyncio.get_event_loop()
         coro_notification = loop.create_server(
-            self.notification_factory, port=0)
-        coro = loop.create_server(self.factory,
-                                  self._ws_conf.bind,
-                                  self._ws_conf.port)
+            self.notification_factory,
+            self._ws_conf.notification_bind,
+            self._ws_conf.notification_port)
+        coro = loop.create_server(
+            self.factory,
+            self._ws_conf.bind,
+            self._ws_conf.port)
 
         def got_server(task):
             # Retrieve the port number of the listening socket
             port = task.result().sockets[0].getsockname()[1]
+            if self._ws_conf.notification_bind is not None:
+                host = self._ws_conf.notification_bind
+            else:
+                host = socket.gethostname()
             self.notification_factory.set_subscription_url(
-                'http://%s:%s/' % (self._hostname, port))
+                'http://%s:%s/' % (netutils.escape_ipv6(host), port))
             self._api.set_subscription_factory(self.notification_factory)
 
         task = asyncio.Task(coro_notification)
         task.add_done_callback(got_server)
 
-        loop.run_until_complete(asyncio.wait([coro, task]))
+        loop.run_until_complete(asyncio.gather(coro, task))
 
         try:
             loop.run_forever()
