@@ -13,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from distutils import version as d_version
 import falcon
 import socket
 from wsgiref import simple_server
@@ -32,7 +31,6 @@ from zaqar.transport.middleware import auth
 from zaqar.transport.middleware import cors
 from zaqar.transport.middleware import profile
 from zaqar.transport import validation
-from zaqar.transport.wsgi import v1_0
 from zaqar.transport.wsgi import v1_1
 from zaqar.transport.wsgi import v2_0
 from zaqar.transport.wsgi import version
@@ -109,7 +107,6 @@ class Driver(transport.DriverBase):
         """Initialize hooks and URI routes to resources."""
 
         catalog = [
-            ('/v1', v1_0.public_endpoints(self, self._conf)),
             ('/v1.1', v1_1.public_endpoints(self, self._conf)),
             ('/v2', v2_0.public_endpoints(self, self._conf)),
             ('/', [('', version.Resource())])
@@ -117,21 +114,12 @@ class Driver(transport.DriverBase):
 
         if self._conf.admin_mode:
             catalog.extend([
-                ('/v1', v1_0.private_endpoints(self, self._conf)),
                 ('/v1.1', v1_1.private_endpoints(self, self._conf)),
                 ('/v2', v2_0.private_endpoints(self, self._conf)),
             ])
 
-        # NOTE(wanghao): Since hook feature has removed after 1.0.0, using
-        # middleware instead of it, but for the compatibility with old version,
-        # we support them both now. Hook way can be removed after falcon
-        # version must be bigger than 1.0.0 in requirements.
-        if (d_version.LooseVersion(falcon.__version__) >=
-                d_version.LooseVersion("1.0.0")):
-            middleware = [FuncMiddleware(hook) for hook in self.before_hooks]
-            self.app = falcon.API(middleware=middleware)
-        else:
-            self.app = falcon.API(before=self.before_hooks)
+        middleware = [FuncMiddleware(hook) for hook in self.before_hooks]
+        self.app = falcon.API(middleware=middleware)
 
         # Set options to keep behavior compatible to pre-2.0.0 falcon
         self.app.req_options.auto_parse_qs_csv = True
@@ -170,8 +158,9 @@ class Driver(transport.DriverBase):
         if isinstance(exc, falcon.HTTPError):
             raise
         LOG.exception('Internal server error')
-        raise falcon.HTTPInternalServerError('Internal server error',
-                                             str(exc))
+        raise falcon.HTTPInternalServerError(
+            title='Internal server error',
+            description=str(exc))
 
     def _get_server_cls(self, host):
         """Return an appropriate WSGI server class base on provided host
@@ -188,7 +177,7 @@ class Driver(transport.DriverBase):
     def listen(self):
         """Self-host using 'bind' and 'port' from the WSGI config group."""
 
-        msgtmpl = _(u'Serving on host %(bind)s:%(port)s')
+        msgtmpl = _('Serving on host %(bind)s:%(port)s')
         LOG.info(msgtmpl,
                  {'bind': self._wsgi_conf.bind, 'port': self._wsgi_conf.port})
         server_cls = self._get_server_cls(self._wsgi_conf.bind)
