@@ -90,7 +90,7 @@ class CollectionResource(object):
             raise wsgi_errors.HTTPBadRequestAPI(str(ex))
 
         except Exception:
-            description = _(u'Claim could not be created.')
+            description = _('Claim could not be created.')
             LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
@@ -102,7 +102,7 @@ class CollectionResource(object):
                          for msg in resp_msgs]
 
             resp.location = req.path + '/' + cid
-            resp.body = utils.to_json({'messages': resp_msgs})
+            resp.text = utils.to_json({'messages': resp_msgs})
             resp.status = falcon.HTTP_201
         else:
             resp.status = falcon.HTTP_204
@@ -138,7 +138,7 @@ class ItemResource(object):
             LOG.debug(ex)
             raise wsgi_errors.HTTPNotFound(str(ex))
         except Exception:
-            description = _(u'Claim could not be queried.')
+            description = _('Claim could not be queried.')
             LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
@@ -152,7 +152,7 @@ class ItemResource(object):
         meta['href'] = req.path
         del meta['id']
 
-        resp.body = utils.to_json(meta)
+        resp.text = utils.to_json(meta)
         # status defaults to 200
 
     @decorators.TransportLog("Claim item")
@@ -180,7 +180,7 @@ class ItemResource(object):
             raise wsgi_errors.HTTPNotFound(str(ex))
 
         except Exception:
-            description = _(u'Claim could not be updated.')
+            description = _('Claim could not be updated.')
             LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
 
@@ -194,6 +194,6 @@ class ItemResource(object):
             resp.status = falcon.HTTP_204
 
         except Exception:
-            description = _(u'Claim could not be deleted.')
+            description = _('Claim could not be deleted.')
             LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
