@@ -39,14 +39,12 @@ registered, there is an optional field:
 import falcon
 import jsonschema
 from oslo_log import log
-import six
 
 from zaqar.common.api.schemas import pools as schema
 from zaqar.common import utils as common_utils
 from zaqar.i18n import _
 from zaqar.storage import errors
 from zaqar.storage import utils as storage_utils
-from zaqar.transport import acl
 from zaqar.transport import utils as transport_utils
 from zaqar.transport.wsgi import errors as wsgi_errors
 from zaqar.transport.wsgi import utils as wsgi_utils
@@ -63,7 +61,6 @@ class Listing(object):
     def __init__(self, pools_controller):
         self._ctrl = pools_controller
 
-    @acl.enforce("pools:get_all")
     def on_get(self, request, response, project_id):
         """Returns a pool listing as objects embedded in an object:
 
@@ -82,7 +79,7 @@ class Listing(object):
         :returns: HTTP | 200
         """
 
-        LOG.debug(u'LIST pools')
+        LOG.debug('LIST pools')
 
         store = {}
         request.get_param('marker', store=store)
@@ -110,7 +107,7 @@ class Listing(object):
         results['pools'] = pools
 
         response.content_location = request.relative_uri
-        response.body = transport_utils.to_json(results)
+        response.text = transport_utils.to_json(results)
         response.status = falcon.HTTP_200
 
 
@@ -131,7 +128,6 @@ class Resource(object):
             'create': validator_type(schema.create)
         }
 
-    @acl.enforce("pools:get")
     def on_get(self, request, response, project_id, pool):
         """Returns a JSON object for a single pool entry:
 
@@ -142,7 +138,7 @@ class Resource(object):
         :returns: HTTP | [200, 404]
         """
 
-        LOG.debug(u'GET pool - name: %s', pool)
+        LOG.debug('GET pool - name: %s', pool)
         data = None
         detailed = request.get_param_as_bool('detailed') or False
 
@@ -151,13 +147,12 @@ class Resource(object):
 
         except errors.PoolDoesNotExist as ex:
             LOG.debug(ex)
-            raise wsgi_errors.HTTPNotFound(six.text_type(ex))
+            raise wsgi_errors.HTTPNotFound(str(ex))
 
         data['href'] = request.path
 
-        response.body = transport_utils.to_json(data)
+        response.text = transport_utils.to_json(data)
 
-    @acl.enforce("pools:create")
     def on_put(self, request, response, project_id, pool):
         """Registers a new pool. Expects the following input:
 
@@ -170,7 +165,7 @@ class Resource(object):
         :returns: HTTP | [201, 204]
         """
 
-        LOG.debug(u'PUT pool - name: %s', pool)
+        LOG.debug('PUT pool - name: %s', pool)
 
         conf = self._ctrl.driver.conf
         data = wsgi_utils.load(request)
@@ -182,40 +177,37 @@ class Resource(object):
         try:
             self._ctrl.create(pool, weight=data['weight'],
                               uri=data['uri'],
-                              group=data.get('group'),
                               options=data.get('options', {}))
             response.status = falcon.HTTP_201
             response.location = request.path
         except errors.PoolCapabilitiesMismatch as e:
-            LOG.exception(e)
-            title = _(u'Unable to create pool')
-            raise falcon.HTTPBadRequest(title, six.text_type(e))
+            title = _('Unable to create pool')
+            LOG.exception(title)
+            raise falcon.HTTPBadRequest(title=title, description=str(e))
         except errors.PoolAlreadyExists as e:
-            LOG.exception(e)
-            raise wsgi_errors.HTTPConflict(six.text_type(e))
+            LOG.exception('Pool "%s" already exists', pool)
+            raise wsgi_errors.HTTPConflict(str(e))
 
-    @acl.enforce("pools:delete")
     def on_delete(self, request, response, project_id, pool):
         """Deregisters a pool.
 
         :returns: HTTP | [204, 403]
         """
 
-        LOG.debug(u'DELETE pool - name: %s', pool)
+        LOG.debug('DELETE pool - name: %s', pool)
 
         try:
             self._ctrl.delete(pool)
         except errors.PoolInUseByFlavor as ex:
-            LOG.exception(ex)
-            title = _(u'Unable to delete')
-            description = _(u'This pool is used by flavors {flavor}; '
-                            u'It cannot be deleted.')
+            title = _('Unable to delete')
+            description = _('This pool is used by flavors {flavor}; '
+                            'It cannot be deleted.')
             description = description.format(flavor=ex.flavor)
-            raise falcon.HTTPForbidden(title, description)
+            LOG.exception(description)
+            raise falcon.HTTPForbidden(title=title, description=description)
 
         response.status = falcon.HTTP_204
 
-    @acl.enforce("pools:update")
     def on_patch(self, request, response, project_id, pool):
         """Allows one to update a pool's weight, uri, and/or options.
 
@@ -229,14 +221,14 @@ class Resource(object):
         :returns: HTTP | 200,400
         """
 
-        LOG.debug(u'PATCH pool - name: %s', pool)
+        LOG.debug('PATCH pool - name: %s', pool)
         data = wsgi_utils.load(request)
 
-        EXPECT = ('weight', 'uri', 'group', 'options')
+        EXPECT = ('weight', 'uri', 'options')
         if not any([(field in data) for field in EXPECT]):
-            LOG.debug(u'PATCH pool, bad params')
+            LOG.debug('PATCH pool, bad params')
             raise wsgi_errors.HTTPBadRequestBody(
-                'One of `uri`, `weight`, `group`, or `options` needs '
+                'One of `uri`, `weight`,or `options` needs '
                 'to be specified'
             )
 
@@ -251,13 +243,9 @@ class Resource(object):
             )
         fields = common_utils.fields(data, EXPECT,
                                      pred=lambda v: v is not None)
-        resp_data = None
+
         try:
             self._ctrl.update(pool, **fields)
-            resp_data = self._ctrl.get(pool, False)
         except errors.PoolDoesNotExist as ex:
-            LOG.exception(ex)
-            raise wsgi_errors.HTTPNotFound(six.text_type(ex))
-
-        resp_data['href'] = request.path
-        response.body = transport_utils.to_json(resp_data)
+            LOG.exception('Pool "%s" does not exist', pool)
+            raise wsgi_errors.HTTPNotFound(str(ex))
