@@ -14,10 +14,11 @@
 # limitations under the License.
 
 from oslo_log import log as logging
-import six
 
+from zaqar.common import decorators
 from zaqar.i18n import _
 from zaqar.storage import errors as storage_errors
+from zaqar.transport import acl
 from zaqar.transport import utils
 from zaqar.transport.wsgi import errors as wsgi_errors
 
@@ -32,6 +33,8 @@ class Resource(object):
     def __init__(self, queue_controller):
         self._queue_ctrl = queue_controller
 
+    @decorators.TransportLog("Queues stats item")
+    @acl.enforce("queues:stats")
     def on_get(self, req, resp, project_id, queue_name):
         try:
             resp_dict = self._queue_ctrl.stats(queue_name,
@@ -50,11 +53,11 @@ class Resource(object):
                 oldest['href'] = base_path + oldest['id']
                 del oldest['id']
 
-            resp.body = utils.to_json(resp_dict)
+            resp.text = utils.to_json(resp_dict)
             # status defaults to 200
 
         except (storage_errors.QueueDoesNotExist,
-                storage_errors.QueueIsEmpty) as ex:
+                storage_errors.QueueIsEmpty):
             resp_dict = {
                 'messages': {
                     'claimed': 0,
@@ -62,13 +65,13 @@ class Resource(object):
                     'total': 0
                 }
             }
-            resp.body = utils.to_json(resp_dict)
+            resp.text = utils.to_json(resp_dict)
 
         except storage_errors.DoesNotExist as ex:
             LOG.debug(ex)
-            raise wsgi_errors.HTTPNotFound(six.text_type(ex))
+            raise wsgi_errors.HTTPNotFound(str(ex))
 
-        except Exception as ex:
-            LOG.exception(ex)
-            description = _(u'Queue stats could not be read.')
+        except Exception:
+            description = _('Queue stats could not be read.')
+            LOG.exception(description)
             raise wsgi_errors.HTTPServiceUnavailable(description)
